Add Router Policy
Source CIDR
Destination CIDR
Expected Connection Result
Optional: Next Hops (comma delimited)
Router Name

### Description:

Routing policies to apply to router. Policies are matched by most specific source first and then by most specific destination. The next hop addresses can be used to override the router used by the client. Next hop addresses are ignored for Deny action policies.